==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-taskbar/translations/taskbar_hu_HU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<context>
    <name>RazorTaskButton</name>
    <message>
        <location filename="../razortaskbutton.cpp" line="361"/>
        <source>Application</source>
        <translation>Alkalmazás</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="394"/>
        <source>To &amp;Desktop</source>
        <translation>Erre az asztal&amp;ra</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="396"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Az összes asztalra</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="403"/>
        <source>Desktop &amp;%1</source>
        <translation>&amp;%1. asztal</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="410"/>
        <source>&amp;To Current Desktop</source>
        <translation>Az ak&amp;tuális asztalra</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="419"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximalizálás</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="428"/>
        <source>Maximize vertically</source>
        <translation>Maximalizálás függőlegesen</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="433"/>
        <source>Maximize horizontally</source>
        <translation>Maximalizálás vízszintesen</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="439"/>
        <source>&amp;Restore</source>
        <translation>&amp;Visszaállítás</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="443"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimalizálás</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="449"/>
        <source>Roll down</source>
        <translation>Legördítés</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="455"/>
        <source>Roll up</source>
        <translation>Felgördítés</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="464"/>
        <source>&amp;Layer</source>
        <translation>Réte&amp;]</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="466"/>
        <source>Always on &amp;top</source>
        <translation>Mindig &amp;felül</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="471"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normál</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="476"/>
        <source>Always on &amp;bottom</source>
        <translation>Min&amp;dig alul</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="484"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="14"/>
        <source>Razor Task Manager Settings</source>
        <translation>A Razor feladatkezelő beállításai</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="20"/>
        <source>Window List Content</source>
        <translation>Az ablaklista tartalma</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="26"/>
        <source>Show windows from current desktop</source>
        <translation>A jelenlegi asztal ablakai</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="29"/>
        <location filename="../razortaskbarconfiguration.ui" line="39"/>
        <source>wlcB</source>
        <translation>wlcB</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="36"/>
        <source>Show windows from all desktops</source>
        <translation>Az összes asztal ablakai</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="49"/>
        <source>Window List Appearance</source>
        <translation>Az ablaklista megjelenése</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="55"/>
        <source>Button style</source>
        <translation>Gombstílus:</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="65"/>
        <source>Max button width</source>
        <translation>Max. gombszélesség:</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="42"/>
        <source>Icon and text</source>
        <translation>Ikon és szöveg</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="43"/>
        <source>Only icon</source>
        <translation>Csak ikon</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="44"/>
        <source>Only text</source>
        <translation>Csak szöveg</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-taskbar/translations/taskbar_hu_HU.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu_HU" version="2.0">
<context>
    <name>RazorTaskButton</name>
    <message>
        <source>Application</source>
        <translation>Alkalmazás</translation>
    </message>
    <message>
        <source>To &amp;Desktop</source>
        <translation>Erre az asztal&amp;ra</translation>
    </message>
    <message>
        <source>&amp;All Desktops</source>
        <translation>&amp;Az összes asztalra</translation>
    </message>
    <message>
        <source>Desktop &amp;%1</source>
        <translation>&amp;%1. asztal</translation>
    </message>
    <message>
        <source>&amp;To Current Desktop</source>
        <translation>Az ak&amp;tuális asztalra</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximalizálás</translation>
    </message>
    <message>
        <source>Maximize vertically</source>
        <translation>Maximalizálás függőlegesen</translation>
    </message>
    <message>
        <source>Maximize horizontally</source>
        <translation>Maximalizálás vízszintesen</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Visszaállítás</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimalizálás</translation>
    </message>
    <message>
        <source>Roll down</source>
        <translation>Legördítés</translation>
    </message>
    <message>
        <source>Roll up</source>
        <translation>Felgördítés</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation>Réte&amp;]</translation>
    </message>
    <message>
        <source>Always on &amp;top</source>
        <translation>Mindig &amp;felül</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normál</translation>
    </message>
    <message>
        <source>Always on &amp;bottom</source>
        <translation>Min&amp;dig alul</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <source>Razor Task Manager Settings</source>
        <translation>A Razor feladatkezelő beállításai</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation>Az ablaklista tartalma</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation>A jelenlegi asztal ablakai</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation>Az összes asztal ablakai</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation>Az ablaklista megjelenése</translation>
    </message>
    <message>
        <source>Button style</source>
        <translation>Gombstílus:</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation>Max. gombszélesség:</translation>
    </message>
    <message>
        <source>Close on middle-click</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon and text</source>
        <translation>Ikon és szöveg</translation>
    </message>
    <message>
        <source>Only icon</source>
        <translation>Csak ikon</translation>
    </message>
    <message>
        <source>Only text</source>
        <translation>Csak szöveg</translation>
    </message>
</context>
</TS>
